@@ -19,16 +19,24 @@
 #' @param x  character, describes a time duration, i.e. "3m15s"
 #'
 #' @return numeric, number of seconds
-#' @examples
-#'   secs("45s")
-#'   secs("3m15s")
-#'   secs("1h1m5s")
 #'
 #' @seealso \code{\link{embed_youtube}}, \code{\link{hms}}
 #' @export
 #
 secs <- function(x){
 
+  .Deprecated("use_start_time")
+
+  .secs(x)
+}
+
+# internal function
+# @examples
+#   secs("45s")
+#   secs("3m15s")
+#   secs("1h1m5s")
+.secs <- function(x) {
+
   parse <- function(x, char){
     regex <- paste0("(\\d+)", char)
 
@@ -51,6 +59,7 @@ secs <- function(x){
   result
 }
 
+
 #' Create an hours-minutes-seconds string
 #'
 #' @param x, numeric (number of seconds), or character (i.e. "3m15s")
@@ -58,13 +67,21 @@ secs <- function(x){
 #' @return character string (i.e. "0h3m15s")
 #' @seealso \code{\link{secs}}
 #' @export
-#' @examples
-#'   hms(30)
-#'   hms("3m15s")
 #'
 hms <- function(x){
 
-  seconds <- secs(x)
+  .Deprecated("use_start_time")
+
+  .hms(x)
+}
+
+# internal function
+# @examples
+#   hms(30)
+#   hms("3m15s")
+#
+.hms <- function(x) {
+  seconds <- .secs(x)
 
   h <- floor(seconds/3600)
   m <- floor((seconds %% 3600)/60)
@@ -72,3 +89,4 @@ hms <- function(x){
 
   paste0(h, "h", m, "m", s, "s")
 }
+
