@@ -17,7 +17,7 @@
 #' "autoplay" is set to TRUE, and you cannot unset it.
 #'
 #' @rdname use_start_time
-#' @param ...         generic argumentss to pass through
+#' @param ...         generic arguments to pass through
 #' @param embed       embed object made using an \code{\link{embed}} function
 #' @param start_time  numeric (seconds), or character ("3m15s")
 #' @param is_paused   logical, for "Channel 9" specifies if the video
@@ -48,7 +48,7 @@ use_start_time.embed_youtube <- function(embed, start_time, ...){
   url <- httr::parse_url(src)
 
   # set the time in url$query
-  url$query$start <- secs(start_time)
+  url$query$start <- .secs(start_time)
 
   # set the url in the embed
   # == need to ask about a public API for this in htmltools ==
@@ -69,7 +69,7 @@ use_start_time.embed_vimeo <- function(embed, start_time, ...){
   url <- httr::parse_url(src)
 
   # set the time in url$fragment
-  url$fragment <- paste0("t=", secs(start_time))
+  url$fragment <- paste0("t=", .secs(start_time))
 
   # set the url in the embed
   # == need to ask about a public API for this in htmltools ==
@@ -90,7 +90,7 @@ use_start_time.embed_channel9 <- function(embed, start_time, is_paused = TRUE, .
   url <- httr::parse_url(src)
 
   # set the time in url$fragment
-  frag <- paste("time", hms(start_time), sep = "=")
+  frag <- paste("time", .hms(start_time), sep = "=")
 
   if (is_paused){
     frag <- paste(frag, "paused", sep = ":")
